% Determines the element weight at a point p using the Bayliss nbar
% circular distribution.
%      p= radius point where element weight is calculated s.t. 0<=p<=1
%      S=side lobe level in dB
%      nbar=the number of zeros to be moved
% 
% Antenna Arrays a Computational Approach
% Author: Randy L. Haupt
% 2010
% This program is only intended for demonstrations of book examples.
%

function f=baycirpt(p,S,nbar)

A=1/pi*acosh(10^(S/20));     %side lobe level
for ic=1:nbar+1
    mu(ic)=fzero('J1p',(.745+(ic-1))*3);
end

nbar1=nbar-1;
sig2=mu(nbar+1)^2/(A^2+nbar^2);

A=0.3038753+S*(0.05042922+S*(-0.00027989+S*(0.343*10^-5-S*(0.2*10^-7))));
z(1)=0.9858302+S*(0.0333885+S*(0.00014064+S*(-0.19*10^-5+S*(0.1*10^-7))));
z(2)=2.00337487+S*(0.01141548+S*(0.0004159+S*(-0.373*10^-5+S*(0.1*10^-7))));
z(3)=3.00636321+S*(0.00683394+S*(0.00029281+S*(-0.161*10^-5)));
z(4)=4.00518423+S*(0.00501795+S*(0.00021735+S*(-0.88*10^-6)));
Umax=0.4797212+S*(0.01456692+S*(-0.00018739+S*(0.218*10^-5+S*(-0.1*10^-7))));

for ic=1:nbar-1
    if ic<5
        U(ic)=mu(nbar+1)*sqrt(z(ic)^2/(A^2+nbar^2));
    else
        U(ic)=mu(nbar+1)*sqrt((A^2+ic^2)/(A^2+nbar^2));
    end
end
mu
U
%Calculate bayliss weights
    tt=0;
    for m=0:nbar1
        t1=besselj(1,p*mu(m+1))/besselj(1,mu(m+1));
        t2=1;
        for n=1:nbar1
            t2=t2*(1-(mu(m+1))^2/U(n)^2);
        end
        t3=1;
        for n=0:nbar1
            if n~=m
                t3=t3*(1-mu(m+1)^2/mu(n+1)^2);
            end
        end
        tt=tt+(mu(m+1)/pi)^2*t1*t2/t3;
        %b(m+1)=(mu(m+1)/pi)^2/besselj(1,mu(m+1))*t2/t3;
    end
    f=2*tt;                   %weight at p
    