% elementpat
% called from planaraf
% 
% Antenna Arrays a Computational Approach
% Author: Randy L. Haupt
% 2010
% This program is only intended for demonstrations of book examples.
%

function f=elementpat(t,p,ip)

[nr nc]=size(t);
k=2*pi;

if ip==1  % isotropic point source
    Et=ones(nr,nc);
    Ep=zeros(nr,nc);
    dir=1;
elseif ip==2  % Hertzian dipole
    Ix=1; Iy=0;
    Et=Ix*cos(t).*cos(p)+Iy*cos(t).*sin(p);
    Ep=Ix*sin(p)+Iy*cos(p);
    dir=1.5;
elseif ip==3  % Half wavelength dipole
    L=.4; W=.4; kW=k*W;
    Et=cos(p).*cos(pi*L*sin(t).*cos(p)).*sinc(W*sin(t).*sin(p));
    Ep=cos(t).*sin(p).*cos(pi*L*sin(t).*cos(p)).*sinc(W*sin(t).*sin(p));
    dir=2*(k*W)^2./(-2+cos(kW)+kW*fsin(2*kW/pi)*+sinc(kW/pi))
elseif ip==4  % Helix
    N=6;
    d=.25;
    D=1/pi;
    psi=k*d*(cos(t)-1-1/d);
    Et=sin(pi/2/N)*sin(N*psi/2)./sin(psi/2).*cos(t);
    Ep=zeros(nr,nc);
    dir=8.3*(pi*D)^(sqrt(N+2)-1)*(N*d)^0.8*(0.2217*pi*D/d)^(sqrt(N)/2);
elseif ip==5  % uniform rectangular slot
    a=.4;
    b=.4;
    X=a*sin(t).*cos(p);
    Y=b*sin(t).*sin(p);
    Et=sin(p).*sinc(X).*sinc(Y);
    Ep=cos(t).*cos(p).*sinc(X).*sinc(Y);
    dir=4*pi*a*b;
elseif ip==6  % uniform circular slot
    a=5;
    Y=k*a*sin(t);
    Et=sin(p).*besselj(1,Y+.001)./(Y+.001);
    Ep=cos(t).*cos(p).*besselj(1,Y+.001)./(Y+.001);
    dir=4*pi*pi*a^2;
elseif ip==7  % open-end rectangular waveguide
    a=.763; b=.34;
    X=a*sin(t).*cos(p);
    Y=b*sin(t).*sin(p);
    Et=sin(p).*cos(X)./((pi/2)^2-X.^2).*sinc(Y);
    Ep=cos(t).*cos(p).*cos(X)./((pi/2)^2-X.^2).*sinc(Y);
    dir=4*pi*a*b*8/pi^2;
elseif ip>=8  % horn antenna
    lam=3;
    a=2.286/lam; b=1.016/lam; B=10.7/lam; A=13.8/lam; L=6; 
    r1=B/2/sin(atan((B/2-b/2)/L));r2=A/2/sin(atan((A/2-a/2)/L));
    c1=sqrt(1/pi/k/r2);
    c2=k*A/2;
    ky=k*sin(t).*sin(p);
    t1=sqrt(1/pi/k/r1)*(-k*B/2-ky*r1);
    t2=sqrt(1/pi/k/r1)*(k*B/2-ky*r1);
    np=length(p);

    kxp=k*sin(t).*cos(p)+pi/A;
    t1p=c1*(-c2-kxp*r2);
    t2p=c1*(c2-kxp*r2);

    kxpp=k*sin(t).*cos(p)-pi/A;
    t1pp=c1*(-c2-kxpp*r2);
    t2pp=c1*(c2-kxpp*r2);

    c3=.5*sqrt(pi*r2/k);
    c4=exp(j*(kxp.^2*r2/2/k));
    c5=exp(j*(kxpp.^2*r2/2/k));
    I1=0; I2=0;
    if ip>=9
        for ic=1:np
            I1(ic)=c3*c4(ic)*(fcos(t2p(ic))-fcos(t1p(ic))-j*(fsin(t2p(ic))-fsin(t1p(ic))))+c5(ic)*(fcos(t2pp(ic))-fcos(t1pp(ic))-j*(fsin(t2pp(ic))-fsin(t1pp(ic))));
        end
        k1=sqrt(r2)/A; k2=B/sqrt(2*r2);
        u=(k1+1/k1)/sqrt(2);
        v=(k1-1/k1)/sqrt(2);
        DH=4*pi*b*r2/A*((fcos(u)-fcos(v))^2+(fsin(u)-fsin(v))^2)
    end
    if ip==8 | ip==10
        for ic=1:np
            I2(ic)=exp(j*ky(ic)^2*r1/2/k).*(fcos(t2(ic))-fcos(t1(ic))-j*(fsin(t2(ic))-fsin(t1(ic))));
        end
        DE=64*a*r1/pi/B*(fcos(B/sqrt(2*r1))^2+fsin(B/sqrt(2*r1))^2)
    end

    if ip==8   % E-plane
        X=k*a/2*sin(t).*cos(p)+.001;
        Et=sin(p).*(1+cos(t)).*I2.*cos(X)./(X.^2-(pi/2)^2);
        Ep=cos(p).*(1+cos(t)).*I2.*cos(X)./(X.^2-(pi/2)^2);
        dir=DE;
    elseif ip==9 % H-plane
        Y=k*b/2*sin(t).*sin(p)+.001;
        Et=sin(p).*(1+cos(t)).*I1.*sinc(Y/pi);
        Ep=cos(p).*(1+cos(t)).*I1;
        dir=DH;
    elseif ip==10 % pyramidal
        Et=sin(p).*(1+cos(t)).*I1.*I2;
        Ep=cos(p).*(1+cos(t)).*I1.*I2;
        dir=pi/32/a/b*DE*DH;
    end

end

f=sqrt(dir)*sqrt(abs(Et).^2+abs(Ep).^2);