% Determines the element weight at a point p using the Taylor nbar
% circular distribution. Used in squaretay.m.
%      p= radius point where element weight is calculated s.t. 0<=p<=1
%      slldb=side lobe level in dB
%      nbar=the number of zeros to be moved
% 
% Antenna Arrays a Computational Approach
% Author: Randy L. Haupt
% 2010
% This program is only intended for demonstrations of book examples.
%

function tt=taycirpt(p,slldb,nbar)

A=1/pi*acosh(10^(slldb/20));     %side lobe level
for ic=1:nbar
    mu(ic)=fzero('besselj(1,x)',(3.8+(ic-1)*pi));
end

nbar1=nbar-1;

for ic=1:nbar1
    U(ic)=mu(nbar)*sqrt((A^2+(ic-.5)^2)/(A^2+(nbar-.5)^2));
end

%Calculate taylor weights
tt=0;
for m=0:nbar1
    if m==0
        B(1)=1;
    else
        t1=-1/besselj(0,mu(m));
        t2=1;
        for n=1:nbar1
            t2=t2*(1-(mu(m))^2/U(n)^2);
        end
        t3=1;
        for n=1:nbar1
            if n~=m
                t3=t3*(1-mu(m)^2/mu(n)^2);
            end
        end
        B(m+1)=t1*t2/t3;
    end
    if m==0
        tt=1;
    else
    tt=tt+B(m+1)*besselj(0,p*mu(m));
    end
end
